@@ -6,13 +6,15 @@
 
     A friendly wrapper for SQLAlchemy.
 
-    :copyright: 2012-2015 by `Juan-Pablo Scaletti <http://jpscaletti.com>`_.
-    :copyright: 2010 by Armin Ronacher.
+    :copyright: 2013-2017 by `Juan-Pablo Scaletti <http://jpscaletti.com>`_.
     :license: BSD, see LICENSE for more details.
 
+    Some of the code was extracted and adapted from
+    Flask-SQLAlchemy <http://flask-sqlalchemy.pocoo.org/>
+
 """
 from .main import SQLAlchemy, BaseQuery, Model  # noqa
 from .paginator import Paginator, sanitize_page_number  # noqa
 from .helpers import get_debug_queries  # noqa
 
-__version__ = '1.5.2'
+__version__ = '1.8.0'
